#!/bin/sh -e

. ../xi-sys.cfg

fmt -s -w $(tput cols) <<-EOF
    ========================
    Nagios XI Core 4 Upgrade
    ========================

    This script will upgrade a Nagios XI server to Nagios Core 4.

    IMPORTANT: 
    THIS SHOULD ONLY BE DONE IN A TEST ENVIRONMENT
    EXPECT THINGS TO NOT WORK AFTER PERFORMING THIS UPGRADE
    
EOF
read -p "Do you want to continue? [Y/n] " res

case "$res" in
    Y | y | "")
        echo "Proceeding with upgrade..."
        ;;
    *)
        echo "Installation cancelled"
        exit 0
esac

######################################
#   Core 4 Section
######################################
(

    coreversion="nagios-4.0.2"

    echo "Getting $coreversion..."

    # wget http://prdownloads.sourceforge.net/sourceforge/nagios/$coreversion.tar.gz
    tar xzf $coreversion.tar.gz
    
	# apply patches
	./apply-patches "$coreversion"
	
    #compile core
    cd $coreversion
    ./configure --with-command-group=nagcmd
    make all
    make install
    
    #comment out deprecated config items
    sed -i 's/^old/#new/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/use_embedded_perl_implicitly/#use_embedded_perl_implicitly/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/^sleep_time/#sleep_time/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/^p1_file/#p1_file/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/^external_command_buffer_slots/#external_command_buffer_slots/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/^enable_embedded_perl/#enable_embedded_perl/g' /usr/local/nagios/etc/nagios.cfg
    sed -i 's/^command_check_interval/#command_check_interval/g' /usr/local/nagios/etc/nagios.cfg
)

######################################
#   Ndoutil 2 Section
######################################

(
    # we need subversion until we package this into a tarball
    yum install -y git
    
	rm -rf ndoutils
    
	# get ndo svn
    echo "Getting ndoutils 2.0 from version control..."
    git clone git://git.code.sf.net/p/nagios/ndoutils ndoutils
    
    #compile ndo
    cd ndoutils
    git checkout -b ndoutils-2-0 origin/ndoutils-2-0
    ./configure; make; make install
    cp -f src/ndomod-4x.o /usr/local/nagios/bin/ndomod.o
    # Copy 4.x daemon
    cp -f src/ndo2db-4x /usr/local/nagios/bin/ndo2db
    # Copy utilities
    cp -f src/file2sock /usr/local/nagios/bin/
    cp -f src/log2ndo /usr/local/nagios/bin/
    cp -f src/sockdebug /usr/local/nagios/bin/

    ##parse values in case mysql is offloaded 
    ndopass=$(sed -n '/^db_pass=/ s///p' /usr/local/nagios/etc/ndo2db.cfg)
    ndohost=$(sed -n '/^db_host=/ s///p' /usr/local/nagios/etc/ndo2db.cfg)
    ndouser=$(sed -n '/^db_user=/ s///p' /usr/local/nagios/etc/ndo2db.cfg)

	# Remove references to failure_prediction_enabled when we upgrade
	echo "Removing depricated failure_prediction_enabled from NagiosQL"
	echo "delete from tbl_variabledefinition where name='failure_prediction_enabled';"|mysql -p"$mysqlpass" nagiosql
	
	echo "Upgrading DB"
    (
        cd db
		# hack until upgradedb get modified to include all upgrade scripts
		cat mysql-upgrade-2.0.0.sql | mysql -u "$ndouser" -p"$ndopass" -h "$ndohost" nagios
		
		# normal upgrade
        ./upgradedb -u "$ndouser" -p "$ndopass" -h "$ndohost" -d nagios
    )
    
)


#start services
service ndo2db restart
service nagios restart

(
	cd $proddir/scripts
	./reconfigure_nagios.sh
)


fmt -s -w $(tput cols) <<-EOF
    ========================
    Nagios XI Core 4 Upgrade
    ========================

    Nagios XI server has been sucessfully upgraded to Nagios Core 4
    and Ndo2db 2.0

    IMPORTANT: 
    THIS SHOULD ONLY BE DONE IN A TEST ENVIRONMENT
    EXPECT THINGS TO NOT WORK AFTER PERFORMING THIS UPGRADE
    
    Please post bug report to the Nagios XI Forum
    
    Thanks
    
EOF

